CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
66 lines
1.8 KiB
Plaintext
66 lines
1.8 KiB
Plaintext
// Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
//
|
|
// SPDX-License-Identifier: MIT
|
|
|
|
// [sphinx-start]
|
|
#include <hip/hip_runtime.h>
|
|
|
|
#include <iostream>
|
|
|
|
#define HIP_CHECK(expression) \
|
|
{ \
|
|
const hipError_t err = expression; \
|
|
if(err != hipSuccess) \
|
|
{ \
|
|
std::cerr << "HIP error: " \
|
|
<< hipGetErrorString(err) \
|
|
<< " at " << __LINE__ << "\n"; \
|
|
} \
|
|
}
|
|
|
|
// Addition of two values.
|
|
__global__ void add(int *a, int *b, int *c)
|
|
{
|
|
*c = *a + *b;
|
|
}
|
|
|
|
int main()
|
|
{
|
|
int *a, *b, *c;
|
|
int deviceId;
|
|
HIP_CHECK(hipGetDevice(&deviceId)); // Get the current device ID
|
|
|
|
// Allocate memory for a, b and c that is accessible to both device and host codes.
|
|
HIP_CHECK(hipMallocManaged(&a, sizeof(*a)));
|
|
HIP_CHECK(hipMallocManaged(&b, sizeof(*b)));
|
|
HIP_CHECK(hipMallocManaged(&c, sizeof(*c)));
|
|
|
|
// Setup input values.
|
|
*a = 1;
|
|
*b = 2;
|
|
|
|
// Prefetch the data to the GPU device.
|
|
HIP_CHECK(hipMemPrefetchAsync(a, sizeof(*a), deviceId, 0));
|
|
HIP_CHECK(hipMemPrefetchAsync(b, sizeof(*b), deviceId, 0));
|
|
HIP_CHECK(hipMemPrefetchAsync(c, sizeof(*c), deviceId, 0));
|
|
|
|
// Launch add() kernel on GPU.
|
|
add<<<1, 1>>>(a, b, c);
|
|
|
|
// Prefetch the result back to the CPU.
|
|
HIP_CHECK(hipMemPrefetchAsync(c, sizeof(*c), hipCpuDeviceId, 0));
|
|
|
|
// Wait for the prefetch operations to complete.
|
|
HIP_CHECK(hipDeviceSynchronize());
|
|
|
|
// Prints the result.
|
|
std::cout << *a << " + " << *b << " = " << *c << std::endl;
|
|
|
|
// Cleanup allocated memory.
|
|
HIP_CHECK(hipFree(a));
|
|
HIP_CHECK(hipFree(b));
|
|
HIP_CHECK(hipFree(c));
|
|
|
|
return 0;
|
|
}
|
|
// [sphinx-end] |